InputComboBox class

Input comboBox

Inheritance
Implemented types

Constructors

InputComboBox({Key? key, required String name, required String label, bool obrigatorio = false, List<Map<String, dynamic>>? dados, Function? function, String? endpoint, bool composto = true})
composto: Recebe o setValue com id e descricao, senão somente o valor (o value do map não é outro map). Retorna o getValue com id e descricao, senao somente retorna um valor (Não vai ser um map)

Properties

composto → bool
final
controller → InputComboboxController
final
dados → List<Map<String, dynamic>>?
final
endpoint → String?
final
filtro → List<FiltroBase>
final
function → Function?
final
hashCode → int
The hash code for this object.
no setterinherited
items → ObservableList<Map<String, dynamic>>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
final
name → String
Key do map para pegar a informação da api
final
obrigatorio → bool
final
response → List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setteroverride

Methods

clean() → void
override
contemValor() → bool
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<InputComboBox>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getValue() → Map<String, dynamic>
Retorna o map com a chave sendo o get Name
override
inicializar() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFiltro(List<FiltroBase> filtros) → void
setValue(Map<String, dynamic> values) → void
Recebe um map e preencher o input. Pesquise o valor de acordo com a key do metood get name
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited